@@ -11,24 +11,20 @@ __all__ = (b'ViewSet',)
 class ViewSet(object):
     views = {}
     excluded_views = ()
-    app_label = None
 
     def __init__(self):
-        app_label = self.app_label
         # Deep copy to allow overrides without overriding the parent class(es).
         self.views = deepcopy(self.views)
         for k in self.excluded_views:
             del self.views[k]
-        self.urls = (self.__build_urls(),
-                     app_label, app_label)
 
     def build_view_from_dict(self, view_dict):
-        view = view_dict[b'view']
+        View = view_dict[b'view']
+        class NewView(View):
+            pass
         for k, v in view_dict.get(b'kwargs', {}).items():
-            if callable(v):
-                v = v(self)
-            setattr(view, k, v)
-        return view
+            setattr(NewView, k, v)
+        return NewView
 
     def build_url_pattern(self, pattern):
         return pattern
@@ -44,7 +40,7 @@ class ViewSet(object):
         }
         return url(**d)
 
-    def __build_urls(self):
-        return patterns(b'',
-            *[self.__build_url(view_dict) for view_dict in self.views.values()]
-        )
+    @property
+    def urls(self):
+        return [self.__build_url(view_dict)
+                for view_dict in self.views.values()]
